==> react-native-web-jsonschema-form-1.0.33.tgz: package/widgets/SelectWidget.js <==
import _withHandlers from "recompact/withHandlers";
import _without from "lodash/without";
import _isArray from "lodash/isArray";
import React from 'react';
import PropTypes from 'prop-types';
import Select from 'react-native-web-ui-components/Select';
import StylePropType from 'react-native-web-ui-components/StylePropType';

const SelectWidget = _withHandlers({
  onWrappedChange: ({
    name,
    schema,
    onChange
  }) => value => {
    let parsedValue = value;

    if (schema.type === 'number' || schema.type === 'integer') {
      parsedValue = parseFloat(value) || null;
    } else if (schema.type === 'boolean') {
      parsedValue = value === 'true';
    }

    onChange(parsedValue, name);
  },
  onWrappedFocus: ({
    name,
    onFocus
  }) => () => onFocus(name)
})(({
  schema,
  uiSchema,
  hasError,
  onWrappedFocus,
  onWrappedChange,
  name,
  focus,
  value,
  readonly,
  disabled,
  placeholder,
  auto,
  style
}) => {
  let values = uiSchema['ui:enum'] || schema.enum || [];

  if (_isArray(uiSchema['ui:enumExcludes'])) {
    values = _without(values, uiSchema['ui:enumExcludes']);
  }

  const labels = uiSchema['ui:enumNames'] || schema.enumNames || values;
  const autoFocus = focus === name || focus === null && uiSchema['ui:autofocus'];
  return React.createElement(Select, {
    disabled: disabled,
    readonly: readonly,
    hasError: hasError,
    auto: auto,
    name: name,
    value: `${value}`,
    values: values.map(v => `${v}`),
    labels: labels,
    autoFocus: autoFocus,
    onFocus: onWrappedFocus,
    onChange: onWrappedChange,
    placeholder: placeholder,
    containerStyle: style
  });
});

SelectWidget.propTypes = {
  schema: PropTypes.shape({}).isRequired,
  uiSchema: PropTypes.shape({}).isRequired,
  hasError: PropTypes.bool.isRequired,
  onFocus: PropTypes.func.isRequired,
  onChange: PropTypes.func.isRequired,
  name: PropTypes.string.isRequired,
  focus: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  auto: PropTypes.bool,
  style: StylePropType
};
SelectWidget.defaultProps = {
  focus: null,
  value: '',
  placeholder: '',
  readonly: false,
  disabled: false,
  auto: false,
  style: null
};
export default SelectWidget;

==> react-native-web-jsonschema-form-1.1.10.tgz: package/widgets/SelectWidget.js <==
import _withHandlers from "recompact/withHandlers";
import _without from "lodash/without";
import _isNaN from "lodash/isNaN";
import _isArray from "lodash/isArray";
import React from 'react';
import PropTypes from 'prop-types';
import Select from 'react-native-web-ui-components/Select';
import StylePropType from 'react-native-web-ui-components/StylePropType';

const SelectWidget = _withHandlers({
  onWrappedChange: ({
    name,
    schema,
    onChange
  }) => value => {
    let parsedValue = value;

    if (schema.type === 'number' || schema.type === 'integer') {
      parsedValue = parseFloat(value);

      if (_isNaN(parsedValue)) {
        parsedValue = null;
      }
    } else if (schema.type === 'boolean') {
      parsedValue = value === 'true';
    }

    onChange(parsedValue, name);
  },
  onWrappedFocus: ({
    name,
    onFocus
  }) => () => onFocus(name)
})(({
  schema,
  uiSchema,
  hasError,
  onWrappedFocus,
  onWrappedChange,
  name,
  focus,
  value,
  readonly,
  disabled,
  placeholder,
  auto,
  style
}) => {
  let values = uiSchema['ui:enum'] || schema.enum || [];

  if (_isArray(uiSchema['ui:enumExcludes'])) {
    values = _without(values, uiSchema['ui:enumExcludes']);
  }

  const labels = uiSchema['ui:enumNames'] || schema.enumNames || values;
  const autoFocus = focus === name || focus === null && uiSchema['ui:autofocus'];
  return React.createElement(Select, {
    disabled: disabled,
    readonly: readonly,
    hasError: hasError,
    auto: auto,
    name: name,
    value: `${value}`,
    values: values.map(v => `${v}`),
    labels: labels,
    autoFocus: autoFocus,
    onFocus: onWrappedFocus,
    onChange: onWrappedChange,
    placeholder: placeholder,
    containerStyle: style
  });
});

SelectWidget.propTypes = {
  schema: PropTypes.shape({}).isRequired,
  uiSchema: PropTypes.shape({}).isRequired,
  hasError: PropTypes.bool.isRequired,
  onFocus: PropTypes.func.isRequired,
  onChange: PropTypes.func.isRequired,
  name: PropTypes.string.isRequired,
  focus: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  auto: PropTypes.bool,
  style: StylePropType
};
SelectWidget.defaultProps = {
  focus: null,
  value: '',
  placeholder: '',
  readonly: false,
  disabled: false,
  auto: false,
  style: null
};
export default SelectWidget;
